package cloud.javastudy.study.demo.controller;

import org.springframework.web.bind.annotation.*;

/**
 * @Author https://www.javastudy.cloud
 * @CreateTime 2019/11/3
 **/
@RestController
public class ParamController {

    /**
     * 这里使用了 GetMapping 和 @RequestMapping(method = RequestMethod.GET)是一样的
     * 在方法入参的位置,把每个参数都平铺开来
     * @return
     */
    @GetMapping("param/handleGetParam1")
    public String handleGetParam1(String param1, String param2){
        String result = String.format("in handle1 param1 is %s, param2 is %s", param1, param2);
        return result;
    }

    /**
     * 把入参封装成一个实体,如果请求参数过多,一般大于5个时,用这种方法
     * @param demo
     * @return
     */
    @GetMapping("param/handleGetParam2")
    public String handleGetParam2(ParamDemo demo){
        String result = String.format("in handle2 param1 is %s, param2 is %s", demo.param1, demo.param2);
        return result;
    }

    /**
     * Post 请求入参也可以这样平铺使用
     * 一般适用于前端Header中Content-Type为application/x-www-form-urlencoded的场景
     * @param param1
     * @param param2
     * @return
     */
    @PostMapping("param/handlePostParam1")
    public String handlePostParam1(String param1, String param2){
        String result = String.format("in handle1 param1 is %s, param2 is %s", param1, param2);
        return result;
    }

    /**
     * 入参为一个实体类的形式,没有任何注解
     * 一般适用于参数个数较多,肯Header中Content-Type为application/x-www-form-urlencoded的场景
     * @param demo
     * @return
     */
    @PostMapping("param/handlePostParam2")
    public String handlePostParam2(@PathVariable ParamDemo demo){
        String result = String.format("in handle2 param1 is %s, param2 is %s", demo.param1, demo.param2);
        return result;
    }

    /**
     * 请求入参是一个实体,并且加上了 @RequestBody
     * 一般适用于前端Header中Content-Type 为 application/json的场景
     * 注意入参要是json格式
     * @param demo
     * @return
     */
    @PostMapping("param/handlePostParam3")
    public String handlePostParam3(@RequestBody ParamDemo demo){
        String result = String.format("in handle2 param1 is %s, param2 is %s", demo.param1, demo.param2);
        return result;
    }

    /**
     * 使用静态内部类,简单定义一个入参实体类
     */
    static class ParamDemo{
        private String param1;
        private String param2;

        public String getParam1() {
            return param1;
        }

        public void setParam1(String param1) {
            this.param1 = param1;
        }

        public String getParam2() {
            return param2;
        }

        public void setParam2(String param2) {
            this.param2 = param2;
        }
    }
}


